icsemantic.catalog.indexes.utils

Package platecom :: Package ontocatalog :: Package indexes :: Module utils |
[hide private]
[frames] | no frames]

# Module utils

source code

A few common pieces of code used in the catalog indexes in this package are grouped into functions in this module to make its reuse easier.

Functions | [hide private]
get_equivalent(portal, k, lang=None) Query the local thesaurus for equivalent concepts | source code
get_related(portal, k, lang=None, context=None) Query the local thesaurus for related concepts | source code
thesaurus_utility(context) Return the local utility for the thesaurus | source code
build_catalog_results(id, catalog, catalog_results) Build a catalog result simulate an internal catalog result | source code